@@ -1,11 +1,9 @@
 import requests
 import json
-from dotenv import load_dotenv, dotenv_values
 import logging
 from urllib.parse import urljoin
 
 class OpenAccess:
-    config = dotenv_values(".env")  # take environment variables from .env.
     # Constants and globals used throughout the class
     instance = None
     # Change 'localhost' to the fully qualified domain name where the OpenAccess service is hosted
@@ -15,19 +13,30 @@ class OpenAccess:
     ERROR = 'ERROR' #config['ERROR']
     API_VERSION = '1.0'#config['API_VERSION']
     APPLICATION_ID = 'APP_ID'#config['APPLICATION_ID']
+    api_url=None
+    application_id=None
 
-    def __init__(self):
+    def __init__(self, api_url=None, application_id=None, ssl_verify=False):
+        '''
+        Init for OpenAccess class
+        Args:
+            api_url [str]: 'api url where Open Access server is located.'
+            application_id [str]: 'Application id needed for open access license.'
+            ssl_verify [bool]: 'Parameter for ssl verify in call request.'
+
+        Return: None
+        '''
         # Set up the requests.Session to handle requests to the OpenAccess API
-        self.base_url = self.API_URL
+        self.base_url = api_url
         self.client = requests.Session()
         self.client.headers.clear()
         self.client.headers.update({
-            "Application-Id": self.APPLICATION_ID,
+            "Application-Id": application_id,
             "Content-Type": "application/json",
             "Accept": "application/json"
         })
-        self.client.verify = False # Temporary solution for invalid security certificate causing an inability to access the api
-        self.client.base_url = self.API_URL
+        self.client.verify = ssl_verify # Temporary solution for invalid security certificate causing an inability to access the api
+        self.client.base_url = api_url
         self.panels = []
 
         # You must initialize logging, otherwise you'll not see debug output.
@@ -59,6 +68,7 @@ class OpenAccess:
         # OpenAccess "instances" request
         # GET /api/access/onguard/openaccess/instances
         # Retrieves instances of a particular type based on the client-supplied filter (above)
+        self.client.headers.update({"Session-Token": self.session_token})
         response = self.client.get(request)
         
         return self.parse_response(response)
@@ -106,6 +116,7 @@ class OpenAccess:
         # OpenAccess "cardholders" request
         # GET /api/access/onguard/openaccess/cardholders
         # Retrieves cardholders based on the client-supplied filter (above)
+        self.client.headers.update({"Session-Token": self.session_token})
         response = self.client.get(request)
         
         return self.parse_response(response)
@@ -142,6 +153,7 @@ class OpenAccess:
         
 
     def get_directories(self):
+        self.client.headers.update({"Session-Token": self.session_token})
         response = self.client.get(self.build_uri_with_version("directories","1.0"))
 
         # If a response is received, parse it into a dictionary so its properties can be retrieved easily
@@ -233,6 +245,7 @@ class OpenAccess:
         }
 
         
+        self.client.headers.update({"Session-Token": self.session_token})
         response = self.client.post_json(self.build_uri_with_version("execute_method"), em)
 
         # If a response is recieved, parse it into a dict so its properties can be retrieved easily
@@ -241,4 +254,4 @@ class OpenAccess:
 
         # If an error occurred on the server side, return its information
         else:
-            return f"A server error occurred during your request. If the status code is available, it is shown below\n{response.status_code}: {response.text}"
+            return f"A server error occurred during your request. If the status code is available, it is shown below\n{response.status_code}: {response.text}"
\ No newline at end of file
